package com.dayou.controller;

import com.dayou.common.BaseEntity;
import com.dayou.entity.ReportHeadline;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.springframework.web.bind.annotation.RestController;
import com.dayou.service.IReportSectionService;
import com.dayou.entity.ReportSection;
import com.dayou.common.RestResponse;
import org.springframework.web.bind.annotation.*;
import com.dayou.common.PullDownModel;
import com.dayou.utils.ConvertUtil;
import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
/**
 * 报告段落模板
 *
 * @author wucl
 * @since 2023-08-25
 */
@RestController
@RequestMapping("reportSection")
@Slf4j
public class ReportSectionController extends BaseController {
    @Autowired
    private IReportSectionService reportSectionService;

    /**
    * 报告段落模板列表
    */
    @GetMapping("")
    public RestResponse<Page<ReportSection>> page(ReportSection reportSection, Page page){
        Page<ReportSection> pages=reportSectionService.selectPage(page,reportSection);
        return RestResponse.data(pages);
    }

    /**
     * 报告段落模板详情
     */
    @GetMapping("/{id}")
    public RestResponse<ReportSection> detail(@PathVariable Long id){
        ReportSection xReportSection =reportSectionService.detail(id);
        return RestResponse.data(xReportSection);
     }

    /**
     * 报告段落模板新增
     */
    @PostMapping("")
    public RestResponse<Boolean> save(@RequestBody ReportSection reportSection) {
        Boolean ret = reportSectionService.add(reportSection);
        return RestResponse.data(ret);
    }

    /**
     * 报告段落模板更新
     */
    @PutMapping("")
    public RestResponse<Boolean> update(@RequestBody ReportSection reportSection) {
        Boolean ret = reportSectionService.update(reportSection);
        return RestResponse.data(ret);
    }

    /**
     * 报告段落模板删除
     */
    @DeleteMapping("/{id}")
    public RestResponse<Boolean> delete(@PathVariable Long id) {
        Boolean ret = reportSectionService.delete(id);
        return RestResponse.data(ret);
    }


    /**
     * 报告段落模板下拉列表
     */
    @GetMapping("/simpleAll")
    public RestResponse<List<PullDownModel>> simpleAll(){
        LambdaQueryWrapper<ReportSection> lambdaQueryWrapper = new LambdaQueryWrapper<ReportSection>()
        .select(ReportSection::getId,ReportSection::getName)
        .eq(ReportSection::getDeleted,false);
        List<ReportSection> list= reportSectionService.list(lambdaQueryWrapper);
        List<PullDownModel> ret=ConvertUtil.copyList(list, PullDownModel.class);
        return RestResponse.data(ret);
    }

    /**
     * 获取段落模板列表不分页
     * @param id
     * @return
     */
    @GetMapping("/headline/{id}")
    public RestResponse<List<ReportSection>> getList(@PathVariable("id") Long id){
        List<ReportSection> list = reportSectionService.list(new LambdaQueryWrapper<ReportSection>().eq(ReportSection::getHeadlineId, id)
                        .isNotNull(ReportSection::getSection)
                .eq(BaseEntity::getDeleted, Boolean.FALSE));
        return RestResponse.data(list);
    }
}

